==> gradio_chessboard-0.0.1-py3-none-any.whl: gradio_chessboard/chessboard.py <==
from __future__ import annotations

from collections.abc import Callable, Sequence
from typing import TYPE_CHECKING, Any, Literal

import chess
from gradio.components.base import Component
from gradio.events import EventListener, Events
from gradio.i18n import I18nData

if TYPE_CHECKING:
    from gradio.components import Timer


class Chessboard(Component):

    EVENTS = [
        Events.submit,
        Events.change,
        EventListener(
            "move",
            doc="Event triggered when a move is made on the chessboard in game mode.",
        ),
    ]

    def __init__(
        self,
        value: str | Callable | None = None,
        *,
        label: str | I18nData | None = None,
        every: Timer | float | None = None,
        inputs: Component | Sequence[Component] | set[Component] | None = None,
        show_label: bool | None = None,
        scale: int | None = None,
        min_width: int = 160,
        interactive: bool | None = None,
        visible: bool = True,
        elem_id: str | None = None,
        elem_classes: list[str] | str | None = None,
        render: bool = True,
        key: int | str | tuple[int | str, ...] | None = None,
        preserved_by_key: list[str] | str | None = "value",
        game_mode: bool = False,
        orientation: Literal["white", "black"] = "white",
    ):
        """
        Parameters:
            game_mode: if True, the chessboard will be rendered in game mode, allowing users to play chess on it. If False, it will be rendered in edit mode, allowing users to edit the chessboard without playing. Defaults to False.
            orientation: the orientation of the chessboard, either "white" or "black". Defaults to "white".
            value: default fen. If a function is provided, the function will be called each time the app loads to set the initial value of this component.
            label: the label for this component, displayed above the component if `show_label` is `True` and is also used as the header if there are a table of examples for this component. If None and used in a `gr.Interface`, the label will be the name of the parameter this component corresponds to.
            every: Continously calls `value` to recalculate it if `value` is a function (has no effect otherwise). Can provide a Timer whose tick resets `value`, or a float that provides the regular interval for the reset Timer.
            inputs: Components that are used as inputs to calculate `value` if `value` is a function (has no effect otherwise). `value` is recalculated any time the inputs change.
            show_label: if True, will display label.
            scale: relative size compared to adjacent Components. For example if Components A and B are in a Row, and A has scale=2, and B has scale=1, A will be twice as wide as B. Should be an integer. scale applies in Rows, and to top-level Components in Blocks where fill_height=True.
            min_width: minimum pixel width, will wrap if not sufficient screen space to satisfy this value. If a certain scale value results in this Component being narrower than min_width, the min_width parameter will be respected first.
            interactive: if True, will be rendered as an editable textbox; if False, editing will be disabled. If not provided, this is inferred based on whether the component is used as an input or output.
            visible: If False, component will be hidden.
            elem_id: An optional string that is assigned as the id of this component in the HTML DOM. Can be used for targeting CSS styles.
            elem_classes: An optional list of strings that are assigned as the classes of this component in the HTML DOM. Can be used for targeting CSS styles.
            render: If False, component will not render be rendered in the Blocks context. Should be used if the intention is to assign event listeners now but render the component later.
            key: in a gr.render, Components with the same key across re-renders are treated as the same component, not a new component. Properties set in 'preserved_by_key' are not reset across a re-render.
            preserved_by_key: A list of parameters from this component's constructor. Inside a gr.render() function, if a component is re-rendered with the same key, these (and only these) parameters will be preserved in the UI (if they have been changed by the user or an event listener) instead of re-rendered based on the values provided during constructor.
        """
        self.game_mode = game_mode
        self.orientation = orientation
        super().__init__(
            label=label,
            every=every,
            inputs=inputs,
            show_label=show_label,
            scale=scale,
            min_width=min_width,
            interactive=interactive,
            visible=visible,
            elem_id=elem_id,
            elem_classes=elem_classes,
            value=value,
            render=render,
            key=key,
            preserved_by_key=preserved_by_key,
        )

    def preprocess(self, payload: str | None) -> chess.Board | None:
        """
        Converts the payload (FEN string) into a chess.Board object.
        Parameters:
            payload: FEN string representing the chessboard state, or None if no payload is provided.
        Returns:
            A chess.Board object if payload is provided, otherwise None.
        """
        return chess.Board(payload) if payload else None

    def postprocess(self, value: chess.Board | None) -> str | None:
        """
        Converts the chess.Board object back into a FEN string.
        Parameters:
            value: A chess.Board object representing the current state of the chessboard, or None if no value is provided.
        Returns:
            A FEN string representing the chessboard state if value is provided, otherwise None.
        """
        return value.fen() if value else None

    def example_payload(self):
        return "rnbqkbnr/pp2pppp/2p5/3p4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq - 0 1"

    def example_value(self):
        return chess.Board(self.example_payload())

    def api_info(self) -> dict[str, Any]:
        return {
            "type": "string",
            "description": "FEN string representing the chessboard state.",
        }

==> gradio_chessboard-0.0.2-py3-none-any.whl: gradio_chessboard/chessboard.py <==
from __future__ import annotations

from collections.abc import Callable, Sequence
from typing import TYPE_CHECKING, Any, Literal

import chess
from gradio.components.base import Component
from gradio.events import EventListener, Events
from gradio.i18n import I18nData

if TYPE_CHECKING:
    from gradio.components import Timer


class Chessboard(Component):

    EVENTS = [
        Events.submit,
        Events.change,
        EventListener(
            "move",
            doc="Event triggered when a move is made on the chessboard in game mode.",
        ),
    ]

    def __init__(
        self,
        value: str | Callable | None = None,
        *,
        label: str | I18nData | None = None,
        every: Timer | float | None = None,
        inputs: Component | Sequence[Component] | set[Component] | None = None,
        show_label: bool | None = None,
        scale: int | None = None,
        min_width: int = 160,
        interactive: bool | None = None,
        visible: bool = True,
        elem_id: str | None = None,
        elem_classes: list[str] | str | None = None,
        render: bool = True,
        key: int | str | tuple[int | str, ...] | None = None,
        preserved_by_key: list[str] | str | None = "value",
        game_mode: bool = False,
        orientation: Literal["white", "black"] = "white",
    ):
        """
        Parameters:
            game_mode: if True, the chessboard will be rendered in game mode, allowing users to play chess on it. If False, it will be rendered in edit mode, allowing users to edit the chessboard without playing. Defaults to False.
            orientation: the orientation of the chessboard, either "white" or "black". Defaults to "white".
            value: default fen. If a function is provided, the function will be called each time the app loads to set the initial value of this component.
            label: the label for this component, displayed above the component if `show_label` is `True` and is also used as the header if there are a table of examples for this component. If None and used in a `gr.Interface`, the label will be the name of the parameter this component corresponds to.
            every: Continously calls `value` to recalculate it if `value` is a function (has no effect otherwise). Can provide a Timer whose tick resets `value`, or a float that provides the regular interval for the reset Timer.
            inputs: Components that are used as inputs to calculate `value` if `value` is a function (has no effect otherwise). `value` is recalculated any time the inputs change.
            show_label: if True, will display label.
            scale: relative size compared to adjacent Components. For example if Components A and B are in a Row, and A has scale=2, and B has scale=1, A will be twice as wide as B. Should be an integer. scale applies in Rows, and to top-level Components in Blocks where fill_height=True.
            min_width: minimum pixel width, will wrap if not sufficient screen space to satisfy this value. If a certain scale value results in this Component being narrower than min_width, the min_width parameter will be respected first.
            interactive: if True, will be rendered as a draggable chessboard; if False, dragging will be disabled. If not provided, this is inferred based on whether the component is used as an input or output.
            visible: If False, component will be hidden.
            elem_id: An optional string that is assigned as the id of this component in the HTML DOM. Can be used for targeting CSS styles.
            elem_classes: An optional list of strings that are assigned as the classes of this component in the HTML DOM. Can be used for targeting CSS styles.
            render: If False, component will not render be rendered in the Blocks context. Should be used if the intention is to assign event listeners now but render the component later.
            key: in a gr.render, Components with the same key across re-renders are treated as the same component, not a new component. Properties set in 'preserved_by_key' are not reset across a re-render.
            preserved_by_key: A list of parameters from this component's constructor. Inside a gr.render() function, if a component is re-rendered with the same key, these (and only these) parameters will be preserved in the UI (if they have been changed by the user or an event listener) instead of re-rendered based on the values provided during constructor.
        """
        self.game_mode = game_mode
        self.orientation = orientation
        super().__init__(
            label=label,
            every=every,
            inputs=inputs,
            show_label=show_label,
            scale=scale,
            min_width=min_width,
            interactive=interactive,
            visible=visible,
            elem_id=elem_id,
            elem_classes=elem_classes,
            value=value,
            render=render,
            key=key,
            preserved_by_key=preserved_by_key,
        )

    def preprocess(self, payload: str | None) -> chess.Board | None:
        """
        Converts the payload (FEN string) into a chess.Board object.
        Parameters:
            payload: FEN string representing the chessboard state, or None if no payload is provided.
        Returns:
            A chess.Board object if payload is provided, otherwise None.
        """
        return chess.Board(payload) if payload else None

    def postprocess(self, value: chess.Board | None) -> str | None:
        """
        Converts the chess.Board object back into a FEN string.
        Parameters:
            value: A chess.Board object representing the current state of the chessboard, or None if no value is provided.
        Returns:
            A FEN string representing the chessboard state if value is provided, otherwise None.
        """
        return value.fen() if value else None

    def example_payload(self):
        return "rnbqkbnr/pp2pppp/2p5/3p4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq - 0 1"

    def example_value(self):
        return chess.Board(self.example_payload())

    def api_info(self) -> dict[str, Any]:
        return {
            "type": "string",
            "description": "FEN string representing the chessboard state.",
        }
